@@ -11,19 +11,19 @@ from woodwork.accessor_utils import (
     init_series,
 )
 from woodwork.column_schema import ColumnSchema
-from woodwork.exceptions import ParametersIgnoredWarning, TypingInfoMismatchWarning
+from woodwork.exceptions import (
+    ParametersIgnoredWarning,
+    TypeValidationError,
+    TypingInfoMismatchWarning,
+)
 from woodwork.indexers import _iLocIndexer, _locIndexer
 from woodwork.logical_types import _NULLABLE_PHYSICAL_TYPES, LatLong, Ordinal
 from woodwork.statistics_utils import _get_box_plot_info_for_column
 from woodwork.table_schema import TableSchema
-from woodwork.utils import (
-    _get_column_logical_type,
-    _is_valid_latlong_series,
-    import_or_none,
-)
+from woodwork.utils import _get_column_logical_type, import_or_none
 
 dd = import_or_none("dask.dataframe")
-ks = import_or_none("databricks.koalas")
+ps = import_or_none("pyspark.pandas")
 
 
 class WoodworkColumnAccessor:
@@ -99,7 +99,17 @@ class WoodworkColumnAccessor:
             )
 
             if validate:
-                self._validate_logical_type(logical_type)
+                if isinstance(logical_type, (Ordinal, LatLong)):
+                    logical_type.validate(self._series)
+                else:
+                    valid_dtype = logical_type._get_valid_dtype(type(self._series))
+                    if valid_dtype != str(self._series.dtype):
+                        raise TypeValidationError(
+                            f"Cannot initialize Woodwork. Series dtype '{self._series.dtype}' is "
+                            f"incompatible with {logical_type} dtype. Try converting series "
+                            f"dtype to '{valid_dtype}' before initializing or use the "
+                            "woodwork.init_series function to initialize."
+                        )
 
             self._schema = ColumnSchema(
                 logical_type=logical_type,
@@ -305,28 +315,6 @@ class WoodworkColumnAccessor:
         # Directly return non-callable Series attributes
         return series_attr
 
-    def _validate_logical_type(self, logical_type):
-        """Validates that a logical type is consistent with the series dtype. Performs additional type
-        specific validation, as required."""
-        valid_dtype = logical_type._get_valid_dtype(type(self._series))
-        if valid_dtype != str(self._series.dtype):
-            raise ValueError(
-                f"Cannot initialize Woodwork. Series dtype '{self._series.dtype}' is "
-                f"incompatible with {logical_type} dtype. Try converting series "
-                f"dtype to '{valid_dtype}' before initializing or use the "
-                "woodwork.init_series function to initialize."
-            )
-
-        if isinstance(logical_type, Ordinal):
-            logical_type._validate_data(self._series)
-        elif isinstance(logical_type, LatLong):
-            if not _is_valid_latlong_series(self._series):
-                raise ValueError(
-                    "Cannot initialize Woodwork. Series does not contain properly formatted "
-                    "LatLong data. Try reformatting before initializing or use the "
-                    "woodwork.init_series function to initialize."
-                )
-
     @_check_column_schema
     def add_semantic_tags(self, semantic_tags):
         """Add the specified semantic tags to the set of tags.
@@ -406,17 +394,17 @@ class WoodworkColumnAccessor:
                 Defaults to True.
 
         Note:
-            The minimum quantiles necessary for outlier detection using the IQR method are the
-            first quartile (0.25) and third quartile (0.75). If these keys are missing from the quantiles dictionary,
-            the following quantiles will be calculated: {0.0, 0.25, 0.5, 0.75, 1.0}, which correspond to
-            {min, first quantile, median, third quantile, max}.
+            The minimum quantiles necessary for building a box plot using the IQR method are the
+            minimum value (0.0 in the quantiles dict), first quartile (0.25), third quartile (0.75), and maximum value (1.0).
+            If no quantiles are provided, the following quantiles will be calculated:
+            {0.0, 0.25, 0.5, 0.75, 1.0}, which correspond to {min, first quantile, median, third quantile, max}.
 
         Returns:
             (dict[str -> float,list[number]]): Returns a dictionary containing box plot information for the Series.
                 The following elements will be found in the dictionary:
 
-                - low_bound (float): the lower bound below which outliers lay - to be used as a whisker
-                - high_bound (float): the high bound above which outliers lay - to be used as a whisker
+                - low_bound (float): the lowest data point in the dataset excluding any outliers - to be used as a whisker
+                - high_bound (float): the highest point in the dataset excluding any outliers - to be used as a whisker
                 - quantiles (list[float]): the quantiles used to determine the bounds.
                     If quantiles were passed in, will contain all quantiles passed in. Otherwise, contains the five
                     quantiles {0.0, 0.25, 0.5, 0.75, 1.0}.
@@ -435,6 +423,23 @@ class WoodworkColumnAccessor:
             include_indices_and_values=include_indices_and_values,
         )
 
+    @_check_column_schema
+    def validate_logical_type(self, return_invalid_values=False):
+        """Validates series data based on the logical type.
+        If a column's dtype does not match its logical type's required dtype,
+        will raise a TypeValidationError even when return_invalid_indices is True.
+
+        Args:
+            return_invalid_values (bool): Whether or not to return invalid data values
+
+        Returns:
+            Series: If return_invalid_values is True, returns invalid data values.
+        """
+        return self.logical_type.validate(
+            series=self._series,
+            return_invalid_values=return_invalid_values,
+        )
+
 
 def _validate_schema(schema, series):
     if not isinstance(schema, ColumnSchema):
@@ -459,9 +464,9 @@ if dd:
         pass
 
 
-if ks:
-    from databricks.koalas.extensions import register_series_accessor
+if ps:
+    from pyspark.pandas.extensions import register_series_accessor
 
     @register_series_accessor("ww")
-    class KoalasColumnAccessor(WoodworkColumnAccessor):
+    class SparkColumnAccessor(WoodworkColumnAccessor):
         pass
