@@ -1,16 +1,15 @@
 import copy
 import warnings
 import weakref
-from typing import Dict, Iterable, List, Set, Union
+from typing import Any, Callable, Dict, Iterable, List, Sequence, Set, Union
 
 import pandas as pd
 
-import woodwork.serialize as serialize
 from woodwork.accessor_utils import (
     _check_table_schema,
     _is_dask_dataframe,
     _is_dataframe,
-    _is_koalas_dataframe,
+    _is_spark_dataframe,
     get_invalid_schema_message,
     init_series,
 )
@@ -22,9 +21,11 @@ from woodwork.exceptions import (
 )
 from woodwork.indexers import _iLocIndexer, _locIndexer
 from woodwork.logical_types import Datetime, LogicalType
+from woodwork.serializers.serializer_base import typing_info_to_dict
+from woodwork.serializers.utils import get_serializer
 from woodwork.statistics_utils import (
+    _get_dependence_dict,
     _get_describe_dict,
-    _get_mutual_information_dict,
     _get_valid_mi_columns,
     _get_value_counts,
     _infer_temporal_frequencies,
@@ -32,15 +33,10 @@ from woodwork.statistics_utils import (
 from woodwork.table_schema import TableSchema
 from woodwork.type_sys.utils import _is_numeric_series, col_is_datetime
 from woodwork.typing import AnyDataFrame, ColumnName, UseStandardTagsDict
-from woodwork.utils import (
-    _get_column_logical_type,
-    _parse_logical_type,
-    import_or_none,
-    import_or_raise,
-)
+from woodwork.utils import _get_column_logical_type, _parse_logical_type, import_or_none
 
 dd = import_or_none("dask.dataframe")
-ks = import_or_none("databricks.koalas")
+ps = import_or_none("pyspark.pandas")
 
 
 class WoodworkTableAccessor:
@@ -304,7 +300,7 @@ class WoodworkTableAccessor:
         return series
 
     def __setitem__(self, col_name, column):
-        series = tuple(pkg.Series for pkg in (pd, dd, ks) if pkg)
+        series = tuple(pkg.Series for pkg in (pd, dd, ps) if pkg)
         if not isinstance(column, series):
             raise ValueError("New column must be of Series type")
 
@@ -628,62 +624,56 @@ class WoodworkTableAccessor:
         Returns:
             dict: Description of the typing information.
         """
-        return serialize.typing_info_to_dict(self._dataframe)
+        return typing_info_to_dict(self._dataframe)
 
     @_check_table_schema
     def to_disk(
-        self, path, format="csv", compression=None, profile_name=None, **kwargs
+        self,
+        path,
+        format="csv",
+        filename=None,
+        data_subdirectory="data",
+        typing_info_filename="woodwork_typing_info.json",
+        compression=None,
+        profile_name=None,
+        **kwargs,
     ):
         """Write Woodwork table to disk in the format specified by `format`, location specified by `path`.
         Path could be a local path or an S3 path.
         If writing to S3 a tar archive of files will be written.
 
         Note:
-            As the engine `fastparquet` cannot handle nullable pandas dtypes, `pyarrow` will be used
-            for serialization to parquet.
-
+            When serializing to parquet, Woodwork typing information will be stored in the parquet file metadata,
+            and not in a separate typing info JSON file. Any value provided for `typing_info_filename` will be ignored.
 
         Args:
-            path (str) : Location on disk to write to (will be created as a directory)
-            format (str) : Format to use for writing Woodwork data. Defaults to csv. Possible values are: {'csv', 'pickle', 'parquet'}.
-            compression (str) : Name of the compression to use. Possible values are: {'gzip', 'bz2', 'zip', 'xz', None}.
-            profile_name (str) : Name of AWS profile to use, False to use an anonymous profile, or None.
-            kwargs (keywords) : Additional keyword arguments to pass as keywords arguments to the underlying serialization method or to specify AWS profile.
+            path (str): Location on disk to write to (will be created as a directory if it does not exist)
+            format (str, optional): Format to use for writing Woodwork data. Defaults to csv. Possible values are: {'csv', 'pickle', 'parquet'}.
+            filename (str, optional): Name to use for the saved data file. Will default to the name of the dataframe or "data" if not specified.
+            data_subdirectory (str, optional): Optional subdirectory to append to `path`. Will default to "data" if not specified.
+            typing_info_filename (str, optional): Optional filename to use for storing Woodwork typing information JSON data.
+                Will default to "woodwork_typing_info.json" if not specified. Will be ignored if serializing to parquet.
+            compression (str, optional): Name of the compression to use. Possible values are: {'gzip', 'bz2', 'zip', 'xz', None}. Defaults to None.
+            profile_name (str, optional): Name of AWS profile to use, False to use an anonymous profile, or None. Defaults to None.
+            kwargs (keywords, optional): Additional keyword arguments to pass as keywords arguments to the underlying serialization method or to specify AWS profile.
         """
-        if format == "csv":
-            default_csv_kwargs = {
-                "sep": ",",
-                "encoding": "utf-8",
-                "engine": "python",
-                "index": False,
-            }
-            if _is_koalas_dataframe(self._dataframe):
-                default_csv_kwargs["multiline"] = True
-                default_csv_kwargs["ignoreLeadingWhitespace"] = False
-                default_csv_kwargs["ignoreTrailingWhitespace"] = False
-            kwargs = {**default_csv_kwargs, **kwargs}
-        elif format in ["parquet", "orc"]:
-            import_error_message = (
-                f"The pyarrow library is required to serialize to {format}.\n"
-                "Install via pip:\n"
-                "    pip install pyarrow\n"
-                "Install via conda:\n"
-                "   conda install pyarrow -c conda-forge"
-            )
-            import_or_raise("pyarrow", import_error_message)
-            kwargs["engine"] = "pyarrow"
-        serialize.write_woodwork_table(
+        serializer_cls = get_serializer(format)
+        serializer = serializer_cls(
+            path=path,
+            filename=filename,
+            data_subdirectory=data_subdirectory,
+            typing_info_filename=typing_info_filename,
+        )
+        serializer.serialize(
             self._dataframe,
-            path,
-            format=format,
             compression=compression,
             profile_name=profile_name,
             **kwargs,
         )
 
     def _sort_columns(self, already_sorted):
-        if _is_dask_dataframe(self._dataframe) or _is_koalas_dataframe(self._dataframe):
-            already_sorted = True  # Skip sorting for Dask and Koalas input
+        if _is_dask_dataframe(self._dataframe) or _is_spark_dataframe(self._dataframe):
+            already_sorted = True  # Skip sorting for Dask and Spark input
         if not already_sorted:
             sort_cols = [self._schema.time_index, self._schema.index]
             if self._schema.index is None:
@@ -771,8 +761,8 @@ class WoodworkTableAccessor:
         if inplace:
             if _is_dask_dataframe(self._dataframe):
                 raise ValueError("Drop inplace not supported for Dask")
-            if _is_koalas_dataframe(self._dataframe):
-                raise ValueError("Drop inplace not supported for Koalas")
+            if _is_spark_dataframe(self._dataframe):
+                raise ValueError("Drop inplace not supported for Spark")
 
         assert all([col_name in self._schema.columns for col_name in cols_to_include])
 
@@ -857,8 +847,8 @@ class WoodworkTableAccessor:
         if inplace:
             if _is_dask_dataframe(self._dataframe):
                 raise ValueError("Rename inplace not supported for Dask")
-            if _is_koalas_dataframe(self._dataframe):
-                raise ValueError("Rename inplace not supported for Koalas")
+            if _is_spark_dataframe(self._dataframe):
+                raise ValueError("Rename inplace not supported for Spark")
             self._dataframe.rename(columns=columns, inplace=True)
             self.init_with_full_schema(schema=new_schema)
             return
@@ -869,19 +859,23 @@ class WoodworkTableAccessor:
 
     @_check_table_schema
     def mutual_information_dict(
-        self, num_bins=10, nrows=None, include_index=False, callback=None
+        self,
+        num_bins=10,
+        nrows=None,
+        include_index=False,
+        callback=None,
+        extra_stats=False,
+        min_shared=25,
+        random_seed=0,
     ):
         """
         Calculates mutual information between all pairs of columns in the DataFrame that
-        support mutual information. Use get_valid_mi_types to see which Logical Types support
-        mutual information:
-        >>> from woodwork.utils import get_valid_mi_types
-        >>> get_valid_mi_types()
-        [Age, AgeFractional, AgeNullable, Boolean, BooleanNullable, Categorical, CountryCode, Datetime, Double, Integer, IntegerNullable, Ordinal, PostalCode, SubRegionCode]
+        support mutual information. Call woodwork.utils.get_valid_mi_types to see which Logical Types support
+        mutual information.
 
         Args:
             num_bins (int): Determines number of bins to use for converting
-                numeric features into categorical.
+                numeric features into categorical. Defaults to 10.
             nrows (int): The number of rows to sample for when determining mutual info.
                 If specified, samples the desired number of rows from the data.
                 Defaults to using all rows.
@@ -889,37 +883,55 @@ class WoodworkTableAccessor:
                 included as long as its LogicalType is valid for mutual information calculations.
                 If False, the index column will not have mutual information calculated for it.
                 Defaults to False.
-            callback (callable, optional): function to be called with incremental updates. Has the following parameters:
-
+            callback (callable, optional): Function to be called with incremental updates. Has the following parameters:
                 - update (int): change in progress since last call
                 - progress (int): the progress so far in the calculations
                 - total (int): the total number of calculations to do
                 - unit (str): unit of measurement for progress/total
                 - time_elapsed (float): total time in seconds elapsed since start of call
-
+            extra_stats (bool):  If True, additional column "shared_rows"
+                recording the number of shared non-null rows for a column
+                pair will be included with the dataframe. Defaults to False.
+            min_shared (int): The number of shared non-null rows needed to
+                calculate. Less rows than this will be considered too sparse
+                to measure accurately and will return a NaN value. Must be
+                non-negative. Defaults to 25.
+            random_seed (int): Seed for the random number generator. Defaults to 0.
         Returns:
             list(dict): A list containing dictionaries that have keys `column_1`,
             `column_2`, and `mutual_info` that is sorted in decending order by mutual info.
             Mutual information values are between 0 (no mutual information) and 1
             (perfect dependency).
         """
-        return _get_mutual_information_dict(
-            self._dataframe, num_bins, nrows, include_index, callback
+        return _get_dependence_dict(
+            dataframe=self._dataframe,
+            measures=["mutual_info"],
+            num_bins=num_bins,
+            nrows=nrows,
+            include_index=include_index,
+            callback=callback,
+            extra_stats=extra_stats,
+            min_shared=min_shared,
+            random_seed=random_seed,
         )
 
     def mutual_information(
-        self, num_bins=10, nrows=None, include_index=False, callback=None
+        self,
+        num_bins=10,
+        nrows=None,
+        include_index=False,
+        callback=None,
+        extra_stats=False,
+        min_shared=25,
+        random_seed=0,
     ):
         """Calculates mutual information between all pairs of columns in the DataFrame that
-        support mutual information. Use get_valid_mi_types to see which Logical Types support
-        mutual information:
-        >>> from woodwork.utils import get_valid_mi_types
-        >>> get_valid_mi_types()
-        [Age, AgeFractional, AgeNullable, Boolean, BooleanNullable, Categorical, CountryCode, Datetime, Double, Integer, IntegerNullable, Ordinal, PostalCode, SubRegionCode]
+        support mutual information. Call woodwork.utils.get_valid_mi_types to see which Logical Types support
+        mutual information.
 
         Args:
             num_bins (int): Determines number of bins to use for converting
-                numeric features into categorical.
+                numeric features into categorical. Defaults to 10.
             nrows (int): The number of rows to sample for when determining mutual info.
                 If specified, samples the desired number of rows from the data.
                 Defaults to using all rows.
@@ -927,14 +939,20 @@ class WoodworkTableAccessor:
                 included as long as its LogicalType is valid for mutual information calculations.
                 If False, the index column will not have mutual information calculated for it.
                 Defaults to False.
-            callback (callable, optional): function to be called with incremental updates. Has the following parameters:
-
+            callback (callable, optional): Function to be called with incremental updates. Has the following parameters:
                 - update (int): change in progress since last call
                 - progress (int): the progress so far in the calculations
                 - total (int): the total number of calculations to do
                 - unit (str): unit of measurement for progress/total
                 - time_elapsed (float): total time in seconds elapsed since start of call
-
+            extra_stats (bool):  If True, additional column "shared_rows"
+                recording the number of shared non-null rows for a column
+                pair will be included with the dataframe. Defaults to False.
+            min_shared (int): The number of shared non-null rows needed to
+                calculate. Less rows than this will be considered too sparse
+                to measure accurately and will return a NaN value. Must be
+                non-negative. Defaults to 25.
+            random_seed (int): Seed for the random number generator. Defaults to 0.
         Returns:
             pd.DataFrame: A DataFrame containing mutual information with columns `column_1`,
             `column_2`, and `mutual_info` that is sorted in decending order by mutual info.
@@ -942,16 +960,273 @@ class WoodworkTableAccessor:
             (perfect dependency).
         """
         mutual_info = self.mutual_information_dict(
-            num_bins, nrows, include_index, callback
+            num_bins=num_bins,
+            nrows=nrows,
+            include_index=include_index,
+            callback=callback,
+            extra_stats=extra_stats,
+            min_shared=min_shared,
+            random_seed=random_seed,
         )
         return pd.DataFrame(mutual_info)
 
+    @_check_table_schema
+    def pearson_correlation_dict(
+        self,
+        nrows=None,
+        include_index=False,
+        callback=None,
+        extra_stats=False,
+        min_shared=25,
+        random_seed=0,
+    ):
+        """
+        Calculates Pearson correlation coefficient between all pairs of columns in the DataFrame that
+        support correlation. Works with numeric and datetime data. Call woodwork.utils.get_valid_pearson_types to
+        see which Logical Types are supported.
+
+        Args:
+            nrows (int): The number of rows to sample for when determining correlation.
+                If specified, samples the desired number of rows from the data.
+                Defaults to using all rows.
+            include_index (bool): If True, the column specified as the index will be
+                included as long as its LogicalType is valid for correlation calculations.
+                If False, the index column will not have the Pearson correlation calculated for it.
+                Defaults to False.
+            callback (callable, optional): Function to be called with incremental updates. Has the following parameters:
+                - update (int): change in progress since last call
+                - progress (int): the progress so far in the calculations
+                - total (int): the total number of calculations to do
+                - unit (str): unit of measurement for progress/total
+                - time_elapsed (float): total time in seconds elapsed since start of call
+            extra_stats (bool):  If True, additional column "shared_rows"
+                recording the number of shared non-null rows for a column
+                pair will be included with the dataframe. Defaults to False.
+            min_shared (int): The number of shared non-null rows needed to
+                calculate. Less rows than this will be considered too sparse
+                to measure accurately and will return a NaN value. Must be
+                non-negative. Defaults to 25.
+            random_seed (int): Seed for the random number generator. Defaults to 0.
+        Returns:
+            list(dict): A list containing dictionaries that have keys `column_1`,
+            `column_2`, and `pearson` that is sorted in decending order by correlation coefficient.
+            Correlation coefficient values are between -1 and 1.
+        """
+        return _get_dependence_dict(
+            dataframe=self._dataframe,
+            measures=["pearson"],
+            nrows=nrows,
+            include_index=include_index,
+            callback=callback,
+            extra_stats=extra_stats,
+            min_shared=min_shared,
+            random_seed=random_seed,
+        )
+
+    def pearson_correlation(
+        self,
+        nrows=None,
+        include_index=False,
+        callback=None,
+        extra_stats=False,
+        min_shared=25,
+        random_seed=0,
+    ):
+        """Calculates Pearson correlation coefficient between all pairs of columns in the DataFrame that
+        support correlation. Works with numeric and datetime data. Call woodwork.utils.get_valid_pearson_types to
+        see which Logical Types are supported.
+
+        Args:
+            nrows (int): The number of rows to sample for when determining correlation.
+                If specified, samples the desired number of rows from the data.
+                Defaults to using all rows.
+            include_index (bool): If True, the column specified as the index will be
+                included as long as its LogicalType is valid for correlation calculations.
+                If False, the index column will not have the Pearson correlation calculated for it.
+                Defaults to False.
+            callback (callable, optional): Function to be called with incremental updates. Has the following parameters:
+                - update (int): change in progress since last call
+                - progress (int): the progress so far in the calculations
+                - total (int): the total number of calculations to do
+                - unit (str): unit of measurement for progress/total
+                - time_elapsed (float): total time in seconds elapsed since start of call
+            extra_stats (bool):  If True, additional column "shared_rows"
+                recording the number of shared non-null rows for a column
+                pair will be included with the dataframe. Defaults to False.
+            min_shared (int): The number of shared non-null rows needed to
+                calculate. Less rows than this will be considered too sparse
+                to measure accurately and will return a NaN value. Must be
+                non-negative. Defaults to 25.
+            random_seed (int): Seed for the random number generator. Defaults to 0.
+        Returns:
+            pd.DataFrame: A DataFrame containing Pearson correlation coefficients with columns `column_1`,
+            `column_2`, and `pearson` that is sorted in decending order by correlation value.
+            Pearson values are between -1 and 1, with 0 meaning no correlation.
+        """
+        pearson_dict = self.pearson_correlation_dict(
+            nrows=nrows,
+            include_index=include_index,
+            callback=callback,
+            extra_stats=extra_stats,
+            min_shared=min_shared,
+            random_seed=random_seed,
+        )
+        return pd.DataFrame(pearson_dict)
+
+    @_check_table_schema
+    def dependence_dict(
+        self,
+        measures="all",
+        num_bins=10,
+        nrows=None,
+        include_index=False,
+        callback=None,
+        extra_stats=False,
+        min_shared=25,
+        random_seed=0,
+    ):
+        """Calculates dependence measures between all pairs of columns in the DataFrame that
+        support measuring dependence. Supports boolean, categorical, datetime, and numeric data.
+        Call woodwork.utils.get_valid_mi_types and woodwork.utils.get_valid_pearson_types
+        for complete lists of supported Logical Types.
+
+        Args:
+            dataframe (pd.DataFrame): Data containing Woodwork typing information
+                from which to calculate dependence.
+            measures (list or str): Which dependence measures to calculate.
+                A list of measures can be provided to calculate multiple
+                measures at once.  Valid measure strings:
+
+                - "pearson": calculates the Pearson correlation coefficient
+                - "mutual_info": calculates the mutual information between columns
+                - "max":  max(abs(pearson), mutual) for each pair of columns
+                - "all": includes columns for "pearson", "mutual_info", and "max"
+            num_bins (int): Determines number of bins to use for converting
+                numeric features into categorical. Defaults to 10. Pearson
+                calculation does not use binning.
+            nrows (int): The number of rows to sample for when determining dependence.
+                If specified, samples the desired number of rows from the data.
+                Defaults to using all rows.
+            include_index (bool): If True, the column specified as the index will be
+                included as long as its LogicalType is valid for measuring dependence.
+                If False, the index column will not be considered. Defaults to False.
+            callback (callable, optional): Function to be called with incremental updates. Has the following parameters:
+
+                - update (int): change in progress since last call
+                - progress (int): the progress so far in the calculations
+                - total (int): the total number of calculations to do
+                - unit (str): unit of measurement for progress/total
+                - time_elapsed (float): total time in seconds elapsed since start of call
+            extra_stats (bool):  If True, additional column "shared_rows"
+                recording the number of shared non-null rows for a column
+                pair will be included with the dataframe. Defaults to False. If
+                the "max" measure is being used, a "measure_used" column will be
+                added that records whether Pearson or mutual information was the
+                maximum dependence for a particular row.
+            min_shared (int): The number of shared non-null rows needed to
+                calculate. Less rows than this will be considered too sparse
+                to measure accurately and will return a NaN value. Must be
+                non-negative. Defaults to 25.
+            random_seed (int): Seed for the random number generator. Defaults to 0.
+        Returns:
+            list(dict): A list containing dictionaries that have keys `column_1`,
+            `column_2`, and keys for the specified dependence measures. The list is
+            sorted in decending order by the first specified measure.
+            Dependence information values are between 0 (no dependence) and 1
+            (perfect dependency). For Pearson, values range from -1 to 1 but 0 is
+            still no dependence.
+        """
+        return _get_dependence_dict(
+            dataframe=self._dataframe,
+            measures=measures,
+            num_bins=num_bins,
+            nrows=nrows,
+            include_index=include_index,
+            callback=callback,
+            extra_stats=extra_stats,
+            min_shared=min_shared,
+            random_seed=random_seed,
+        )
+
+    def dependence(
+        self,
+        measures="all",
+        num_bins=10,
+        nrows=None,
+        include_index=False,
+        callback=None,
+        extra_stats=False,
+        min_shared=25,
+        random_seed=0,
+    ):
+        """Calculates dependence measures between all pairs of columns in the DataFrame that
+        support measuring dependence. Supports boolean, categorical, datetime, and numeric data.
+        Call woodwork.utils.get_valid_mi_types and woodwork.utils.get_valid_pearson_types
+        for complete lists of supported Logical Types.
+
+        Args:
+            dataframe (pd.DataFrame): Data containing Woodwork typing information
+                from which to calculate dependence.
+            measures (list or str): Which dependence measures to calculate.
+                A list of measures can be provided to calculate multiple
+                measures at once.  Valid measure strings:
+
+                - "pearson": calculates the Pearson correlation coefficient
+                - "mutual_info": calculates the mutual information between columns
+                - "max":  max(abs(pearson), mutual) for each pair of columns
+                - "all": includes columns for "pearson", "mutual_info", and "max"
+            num_bins (int): Determines number of bins to use for converting
+                numeric features into categorical. Defaults to 10. Pearson
+                calculation does not use binning.
+            nrows (int): The number of rows to sample for when determining dependence.
+                If specified, samples the desired number of rows from the data.
+                Defaults to using all rows.
+            include_index (bool): If True, the column specified as the index will be
+                included as long as its LogicalType is valid for measuring dependence.
+                If False, the index column will not be considered. Defaults to False.
+            callback (callable, optional): Function to be called with incremental updates. Has the following parameters:
+
+                - update (int): change in progress since last call
+                - progress (int): the progress so far in the calculations
+                - total (int): the total number of calculations to do
+                - unit (str): unit of measurement for progress/total
+                - time_elapsed (float): total time in seconds elapsed since start of call
+            extra_stats (bool):  If True, additional column "shared_rows"
+                recording the number of shared non-null rows for a column
+                pair will be included with the dataframe. Defaults to False. If
+                the "max" measure is being used, a "measure_used" column will be
+                added that records whether Pearson or mutual information was the
+                maximum dependence for a particular row.
+            min_shared (int): The number of shared non-null rows needed to
+                calculate. Less rows than this will be considered too sparse
+                to measure accurately and will return a NaN value. Must be
+                non-negative. Defaults to 25.
+            random_seed (int): Seed for the random number generator. Defaults to 0.
+        Returns:
+            pd.DataFrame: A DataFrame with the columns `column_1`,
+            `column_2`, and keys for the specified dependence measures. The rows
+            are sorted in decending order by the first specified measure.
+            Dependence information values are between 0 (no dependence) and 1
+            (perfect dependency). For Pearson, values range from -1 to 1 but 0 is
+            still no dependence.  Additional columns will be included if the
+            `extra_stats` is True.
+        """
+        dep_dict = _get_dependence_dict(
+            dataframe=self._dataframe,
+            measures=measures,
+            num_bins=num_bins,
+            nrows=nrows,
+            include_index=include_index,
+            callback=callback,
+            extra_stats=extra_stats,
+            min_shared=min_shared,
+            random_seed=random_seed,
+        )
+        return pd.DataFrame(dep_dict)
+
     def get_valid_mi_columns(self, include_index=False):
         """Retrieves a list of columns from the DataFrame with valid Logical Types that support mutual
-        information. Use get_valid_mi_types to see which Logical Types support mutual information:
-        >>> from woodwork.utils import get_valid_mi_types
-        >>> get_valid_mi_types()
-        [Age, AgeFractional, AgeNullable, Boolean, BooleanNullable, Categorical, CountryCode, Datetime, Double, Integer, IntegerNullable, Ordinal, PostalCode, SubRegionCode]
+        information. Call woodwork.utils.get_valid_mi_types to see which Logical Types support mutual information.
 
         Args:
             include_index (bool): If True, the column specified as the index will be
@@ -967,13 +1242,14 @@ class WoodworkTableAccessor:
     @_check_table_schema
     def describe_dict(
         self,
-        include=None,
-        callback=None,
-        extra_stats=False,
-        bins=10,
-        top_x=10,
-        recent_x=10,
-    ):
+        include: Sequence[Union[str, LogicalType]] = None,
+        callback: Callable[[int, int, int, str, float], Any] = None,
+        results_callback: Callable[[pd.DataFrame, pd.Series], Any] = None,
+        extra_stats: bool = False,
+        bins: int = 10,
+        top_x: int = 10,
+        recent_x: int = 10,
+    ) -> Dict[str, dict]:
         """Calculates statistics for data contained in the DataFrame.
 
         Args:
@@ -982,13 +1258,17 @@ class WoodworkTableAccessor:
                 combining any of the three. It follows the most broad specification. Favors logical types
                 then semantic tag then column name. If no matching columns are found, an empty DataFrame
                 will be returned.
-            callback (callable, optional): function to be called with incremental updates. Has the following parameters:
+            callback (callable, optional): Function to be called with incremental updates. Has the following parameters:
 
                 - update (int): change in progress since last call
                 - progress (int): the progress so far in the calculations
                 - total (int): the total number of calculations to do
                 - unit (str): unit of measurement for progress/total
                 - time_elapsed (float): total time in seconds elapsed since start of call
+            results_callback (callable, optional): function to be called with intermediate results. Has the following parameters:
+
+                - results_so_far (pd.DataFrame): the full dataframe calculated so far
+                - most_recent_calculation (pd.Series): the calculations for the most recent column
 
             extra_stats (bool): If True, will calculate a histogram for numeric columns, top values
                 for categorical columns and value counts for the most recent values in datetime columns. Will also
@@ -1011,13 +1291,19 @@ class WoodworkTableAccessor:
             self._dataframe,
             include=include,
             callback=callback,
+            results_callback=results_callback,
             extra_stats=extra_stats,
             bins=bins,
             top_x=top_x,
             recent_x=recent_x,
         )
 
-    def describe(self, include=None, callback=None):
+    def describe(
+        self,
+        include: Sequence[Union[str, LogicalType]] = None,
+        callback: Callable[[int, int, int, str, float], Any] = None,
+        results_callback: Callable[[pd.DataFrame, pd.Series], Any] = None,
+    ) -> pd.DataFrame:
         """Calculates statistics for data contained in the DataFrame.
 
         Args:
@@ -1026,20 +1312,26 @@ class WoodworkTableAccessor:
                 combining any of the three. It follows the most broad specification. Favors logical types
                 then semantic tag then column name. If no matching columns are found, an empty DataFrame
                 will be returned.
-            callback (callable, optional): function to be called with incremental updates. Has the following parameters:
+            callback (callable, optional): Function to be called with incremental updates. Has the following parameters:
 
                 - update (int): change in progress since last call
                 - progress (int): the progress so far in the calculations
                 - total (int): the total number of calculations to do
                 - unit (str): unit of measurement for progress/total
                 - time_elapsed (float): total time in seconds elapsed since start of call
+            results_callback (callable, optional): function to be called with intermediate results. Has the following parameters:
+
+                - results_so_far (pd.DataFrame): the full dataframe calculated so far
+                - most_recent_calculation (pd.Series): the calculations for the most recent column
 
         Returns:
             pd.DataFrame: A Dataframe containing statistics for the data or the subset of the original
             DataFrame that contains the logical types, semantic tags, or column names specified
             in ``include``.
         """
-        results = self.describe_dict(include=include, callback=callback)
+        results = self.describe_dict(
+            include=include, callback=callback, results_callback=results_callback
+        )
         index_order = [
             "physical_type",
             "logical_type",
@@ -1083,15 +1375,17 @@ class WoodworkTableAccessor:
         return _get_value_counts(self._dataframe, ascending, top_n, dropna)
 
     @_check_table_schema
-    def infer_temporal_frequencies(self, temporal_columns=None):
+    def infer_temporal_frequencies(self, temporal_columns=None, debug=False):
         """Infers the observation frequency (daily, biweekly, yearly, etc) of each temporal column
             in the DataFrame. Temporal columns are ones with the logical type Datetime or Timedelta.
-            Not supported for Dask and Koalas DataFrames.
+            Not supported for Dask and Spark DataFrames.
 
         Args:
             temporal_columns (list[str], optional): Columns for which frequencies should be inferred. Must be columns
                 that are present in the DataFrame and are temporal in nature. Defaults to None. If not
                 specified, all temporal columns will have their frequencies inferred.
+            debug (boolean): A flag used to determine if more information should be returned for each temporal column if
+                no uniform frequency was found.
 
         Returns:
             (dict): A dictionary where each key is a temporal column from the DataFrame, and the
@@ -1119,11 +1413,44 @@ class WoodworkTableAccessor:
                     One example of this can be seen when using the business day offset alias ``B``
                     ``pd.date_range(start="2020-01-01", freq="4b", periods=10)``, which is a valid ``freq``
                     parameter when building the date range, but is not then inferrable.
+
+            The algorithm used to infer frequency on noisy data can configured (see https://woodwork.alteryx.com/en/stable/guides/setting_config_options.html#Available-Config-Settings)
+
         """
         return _infer_temporal_frequencies(
-            self._dataframe, temporal_columns=temporal_columns
+            self._dataframe, temporal_columns=temporal_columns, debug=debug
         )
 
+    @_check_table_schema
+    def validate_logical_types(self, return_invalid_values=False):
+        """Validates the dataframe based on the logical types.
+        If a column's dtype does not match its logical type's required dtype,
+        will raise a TypeValidationError even when return_invalid_indices is True.
+
+        Args:
+            return_invalid_values (bool): Whether or not to return invalid data values
+
+        Returns:
+            DataFrame: If return_invalid_values is True, returns invalid data values.
+        """
+        invalid_values = []
+        for column in self.columns:
+            series = self.ww[column]
+            values = series.ww.validate_logical_type(
+                return_invalid_values=return_invalid_values
+            )
+            if values is not None:
+                invalid_values.append(values)
+
+        if return_invalid_values:
+            concat = pd.concat
+            if _is_dask_dataframe(self._dataframe):
+                concat = dd.concat
+            if _is_spark_dataframe(self._dataframe):
+                concat = ps.concat
+
+            return concat(invalid_values, axis=1)
+
 
 def _validate_accessor_params(
     dataframe, index, time_index, logical_types, schema, use_standard_tags
@@ -1167,14 +1494,14 @@ def _check_index(dataframe, index):
         raise ColumnNotPresentError(
             f"Specified index column `{index}` not found in dataframe"
         )
-    if (
-        index is not None
-        and isinstance(dataframe, pd.DataFrame)
-        and not dataframe[index].is_unique
-    ):
-        # User specifies an index that is in the dataframe but not unique
-        # Does not check for Dask as Dask does not support is_unique
-        raise IndexError("Index column must be unique")
+    if index is not None and isinstance(dataframe, pd.DataFrame):
+        # User specifies a dataframe index that is not unique or contains null values
+        # Does not check Dask dataframes to avoid pulling data into memory and Dask does not support is_unique
+        if not dataframe[index].is_unique:
+            raise IndexError("Index column must be unique")
+
+        if dataframe[index].isnull().any():
+            raise IndexError("Index contains null values")
 
 
 def _check_time_index(dataframe, time_index, datetime_format=None, logical_type=None):
@@ -1289,12 +1616,12 @@ if dd:
         pass
 
 
-if ks:
-    from databricks.koalas.extensions import register_dataframe_accessor
+if ps:
+    from pyspark.pandas.extensions import register_dataframe_accessor
 
     @register_dataframe_accessor("ww")
-    class KoalasTableAccessor(WoodworkTableAccessor):
+    class SparkTableAccessor(WoodworkTableAccessor):
         def __init__(self, *args, **kwargs):
             super().__init__(*args, **kwargs)
-            if not ks.get_option("compute.ops_on_diff_frames"):
-                ks.set_option("compute.ops_on_diff_frames", True)
+            if not ps.get_option("compute.ops_on_diff_frames"):
+                ps.set_option("compute.ops_on_diff_frames", True)
