@@ -17,21 +17,10 @@ from woodwork.logical_types import (
     PhoneNumber,
     Unknown,
 )
+from woodwork.tests.testing_utils import pd_to_dask, pd_to_spark
 from woodwork.utils import import_or_none
 
 
-def pd_to_dask(series):
-    dd = pytest.importorskip("dask.dataframe", reason="Dask not installed, skipping")
-    return dd.from_pandas(series, npartitions=2)
-
-
-def pd_to_koalas(series):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(series)
-
-
 @pytest.fixture(scope="session", autouse=True)
 def spark_session():
     pyspark = import_or_none("pyspark.sql")
@@ -51,7 +40,7 @@ def spark_session():
         return spark
 
 
-@pytest.fixture(params=["sample_df_pandas", "sample_df_dask", "sample_df_koalas"])
+@pytest.fixture(params=["sample_df_pandas", "sample_df_dask", "sample_df_spark"])
 def sample_df(request):
     return request.getfixturevalue(request.param)
 
@@ -112,11 +101,53 @@ def sample_df_dask(sample_df_pandas):
 
 
 @pytest.fixture()
-def sample_df_koalas(sample_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
+def sample_df_spark(sample_df_pandas):
+    ps = pytest.importorskip(
+        "pyspark.pandas", reason="Pyspark pandas not installed, skipping"
+    )
+    return ps.from_pandas(sample_df_pandas)
+
+
+@pytest.fixture()
+def sample_df_phone_numbers():
+    return pd.DataFrame(
+        {
+            "phone_number": [
+                "2002007865",
+                "311-311-3156",
+                "422.422.0461",
+                "533 533 8122",
+                "644●644●7865",
+                "(755) 755 7109",
+                "(866) 866-0182",
+                "+1 (977) 977 1779",
+                "+1(288)-288-7772",
+                "+1 399 399 2933",
+                "+1-400-400-1109",
+                "+1.511.511.2289",
+                "+16226229222",
+                "17336330019",
+                "1.844.744.1842",
+                "1●955●855●9272",
+                "1 266 966 2283",
+                "+001 236 248 8482",
+            ]
+        }
+    )
+
+
+@pytest.fixture()
+def sample_df_postal_code():
+    return pd.DataFrame(
+        {
+            "postal_code": [
+                "20020",
+                "07865",
+                "12345-6789",
+                "11111-1111",
+            ]
+        }
     )
-    return ks.from_pandas(sample_df_pandas)
 
 
 @pytest.fixture()
@@ -149,7 +180,7 @@ def datetime_freqs_df_pandas():
     params=[
         "sample_unsorted_df_pandas",
         "sample_unsorted_df_dask",
-        "sample_unsorted_df_koalas",
+        "sample_unsorted_df_spark",
     ]
 )
 def sample_unsorted_df(request):
@@ -195,15 +226,13 @@ def sample_unsorted_df_dask(sample_unsorted_df_pandas):
 
 
 @pytest.fixture()
-def sample_unsorted_df_koalas(sample_unsorted_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(sample_unsorted_df_pandas)
+def sample_unsorted_df_spark(sample_unsorted_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(sample_unsorted_df_pandas)
 
 
 @pytest.fixture(
-    params=["sample_series_pandas", "sample_series_dask", "sample_series_koalas"]
+    params=["sample_series_pandas", "sample_series_dask", "sample_series_spark"]
 )
 def sample_series(request):
     return request.getfixturevalue(request.param)
@@ -223,18 +252,16 @@ def sample_series_dask(sample_series_pandas):
 
 
 @pytest.fixture()
-def sample_series_koalas(sample_series_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(sample_series_pandas.astype("string"))
+def sample_series_spark(sample_series_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(sample_series_pandas.astype("string"))
 
 
 @pytest.fixture(
     params=[
         "sample_datetime_series_pandas",
         "sample_datetime_series_dask",
-        "sample_datetime_series_koalas",
+        "sample_datetime_series_spark",
     ]
 )
 def sample_datetime_series(request):
@@ -255,11 +282,9 @@ def sample_datetime_series_dask(sample_datetime_series_pandas):
 
 
 @pytest.fixture()
-def sample_datetime_series_koalas(sample_datetime_series_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(sample_datetime_series_pandas)
+def sample_datetime_series_spark(sample_datetime_series_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(sample_datetime_series_pandas.astype(str))
 
 
 @pytest.fixture()
@@ -274,11 +299,9 @@ def ordinal_transform_series_dask(ordinal_transform_series_pandas):
 
 
 @pytest.fixture()
-def ordinal_transform_series_koalas(ordinal_transform_series_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(ordinal_transform_series_pandas)
+def ordinal_transform_series_spark(ordinal_transform_series_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(ordinal_transform_series_pandas)
 
 
 @pytest.fixture()
@@ -302,15 +325,13 @@ def time_index_df_dask(time_index_df_pandas):
 
 
 @pytest.fixture()
-def time_index_df_koalas(time_index_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(time_index_df_pandas)
+def time_index_df_spark(time_index_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(time_index_df_pandas)
 
 
 @pytest.fixture(
-    params=["time_index_df_pandas", "time_index_df_dask", "time_index_df_koalas"]
+    params=["time_index_df_pandas", "time_index_df_dask", "time_index_df_spark"]
 )
 def time_index_df(request):
     return request.getfixturevalue(request.param)
@@ -334,18 +355,16 @@ def numeric_time_index_df_dask(numeric_time_index_df_pandas):
 
 
 @pytest.fixture()
-def numeric_time_index_df_koalas(numeric_time_index_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(numeric_time_index_df_pandas)
+def numeric_time_index_df_spark(numeric_time_index_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(numeric_time_index_df_pandas)
 
 
 @pytest.fixture(
     params=[
         "numeric_time_index_df_pandas",
         "numeric_time_index_df_dask",
-        "numeric_time_index_df_koalas",
+        "numeric_time_index_df_spark",
     ]
 )
 def numeric_time_index_df(request):
@@ -403,6 +422,16 @@ def describe_df_pandas():
         np.nan,
     ]
     timedelta_data = datetime_data - pd.Timestamp("2020-01-01")
+    unknown_data = [
+        "unknown1",
+        "unknown5",
+        "unknown3",
+        np.nan,
+        "unknown3",
+        np.nan,
+        "unknown5",
+        "unknown5",
+    ]
 
     return pd.DataFrame(
         {
@@ -415,6 +444,7 @@ def describe_df_pandas():
             "natural_language_col": natural_language_data,
             "timedelta_col": timedelta_data,
             "latlong_col": latlong_data,
+            "unknown_col": unknown_data,
         }
     )
 
@@ -426,11 +456,9 @@ def describe_df_dask(describe_df_pandas):
 
 
 @pytest.fixture()
-def describe_df_koalas(describe_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(
+def describe_df_spark(describe_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(
         describe_df_pandas.applymap(
             lambda tup: [None if pd.isnull(elt) else elt for elt in tup]
             if isinstance(tup, tuple)
@@ -439,7 +467,7 @@ def describe_df_koalas(describe_df_pandas):
     )
 
 
-@pytest.fixture(params=["describe_df_pandas", "describe_df_dask", "describe_df_koalas"])
+@pytest.fixture(params=["describe_df_pandas", "describe_df_dask", "describe_df_spark"])
 def describe_df(request):
     return request.getfixturevalue(request.param)
 
@@ -470,16 +498,14 @@ def df_same_mi_dask(df_same_mi_pandas):
 
 
 @pytest.fixture()
-def df_same_mi_koalas(df_same_mi_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
+def df_same_mi_spark(df_same_mi_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
     df_same_mi_pandas["ints"] = df_same_mi_pandas["ints"].astype("float")
     df_same_mi_pandas["nans"] = df_same_mi_pandas["nans"].astype("float")
-    return ks.DataFrame(df_same_mi_pandas)
+    return ps.from_pandas(df_same_mi_pandas)
 
 
-@pytest.fixture(params=["df_same_mi_pandas", "df_same_mi_dask", "df_same_mi_koalas"])
+@pytest.fixture(params=["df_same_mi_pandas", "df_same_mi_dask", "df_same_mi_spark"])
 def df_same_mi(request):
     return request.getfixturevalue(request.param)
 
@@ -489,6 +515,7 @@ def df_mi_pandas():
     df = pd.DataFrame(
         {
             "ints": pd.Series([1, 2, 1]),
+            "ints2": pd.Series([2, 2, 2]),
             "bools": pd.Series([True, False, True]),
             "strs2": pd.Series(["bye", "hi", "bye"]),
             "strs": pd.Series(["hi", "hi", "hi"]),
@@ -506,14 +533,12 @@ def df_mi_dask(df_mi_pandas):
 
 
 @pytest.fixture()
-def df_mi_koalas(df_mi_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(df_mi_pandas)
+def df_mi_spark(df_mi_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(df_mi_pandas)
 
 
-@pytest.fixture(params=["df_mi_pandas", "df_mi_dask", "df_mi_koalas"])
+@pytest.fixture(params=["df_mi_pandas", "df_mi_dask", "df_mi_spark"])
 def df_mi(request):
     return request.getfixturevalue(request.param)
 
@@ -539,15 +564,13 @@ def df_mi_unique_dask(df_mi_unique_pandas):
 
 
 @pytest.fixture()
-def df_mi_unique_koalas(df_mi_unique_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(df_mi_unique_pandas)
+def df_mi_unique_spark(df_mi_unique_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(df_mi_unique_pandas)
 
 
 @pytest.fixture(
-    params=["df_mi_unique_pandas", "df_mi_unique_dask", "df_mi_unique_koalas"]
+    params=["df_mi_unique_pandas", "df_mi_unique_dask", "df_mi_unique_spark"]
 )
 def df_mi_unique(request):
     return request.getfixturevalue(request.param)
@@ -573,15 +596,13 @@ def categorical_df_dask(categorical_df_pandas):
 
 
 @pytest.fixture()
-def categorical_df_koalas(categorical_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(categorical_df_pandas)
+def categorical_df_spark(categorical_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(categorical_df_pandas)
 
 
 @pytest.fixture(
-    params=["categorical_df_pandas", "categorical_df_dask", "categorical_df_koalas"]
+    params=["categorical_df_pandas", "categorical_df_dask", "categorical_df_spark"]
 )
 def categorical_df(request):
     return request.getfixturevalue(request.param)
@@ -598,7 +619,7 @@ def empty_df_dask(empty_df_pandas):
     return dd.from_pandas(empty_df_pandas, npartitions=2)
 
 
-# Cannot have an empty Koalas DataFrame
+# Cannot have an empty Spark DataFrame
 @pytest.fixture(params=["empty_df_pandas", "empty_df_dask"])
 def empty_df(request):
     return request.getfixturevalue(request.param)
@@ -620,14 +641,13 @@ def small_df_dask(small_df_pandas):
 
 
 @pytest.fixture()
-def small_df_koalas(small_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(small_df_pandas)
+def small_df_spark(small_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    df = small_df_pandas.astype("datetime64[ns]")
+    return ps.from_pandas(df)
 
 
-@pytest.fixture(params=["small_df_pandas", "small_df_dask", "small_df_koalas"])
+@pytest.fixture(params=["small_df_pandas", "small_df_dask", "small_df_spark"])
 def small_df(request):
     return request.getfixturevalue(request.param)
 
@@ -656,18 +676,16 @@ def latlong_df_dask(latlong_df_pandas):
 
 
 @pytest.fixture()
-def latlong_df_koalas(latlong_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(
+def latlong_df_spark(latlong_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(
         latlong_df_pandas.applymap(
             lambda tup: list(tup) if isinstance(tup, tuple) else tup
         )
     )
 
 
-@pytest.fixture(params=["latlong_df_pandas", "latlong_df_dask", "latlong_df_koalas"])
+@pytest.fixture(params=["latlong_df_pandas", "latlong_df_dask", "latlong_df_spark"])
 def latlong_df(request):
     return request.getfixturevalue(request.param)
 
@@ -693,16 +711,16 @@ def dask_latlongs(pandas_latlongs):
 
 
 @pytest.fixture
-def koalas_latlongs(pandas_latlongs):
+def spark_latlongs(pandas_latlongs):
     return [
-        pd_to_koalas(
+        pd_to_spark(
             series.apply(lambda tup: list(tup) if isinstance(tup, tuple) else tup)
         )
         for series in pandas_latlongs
     ]
 
 
-@pytest.fixture(params=["pandas_latlongs", "dask_latlongs", "koalas_latlongs"])
+@pytest.fixture(params=["pandas_latlongs", "dask_latlongs", "spark_latlongs"])
 def latlongs(request):
     return request.getfixturevalue(request.param)
 
@@ -731,15 +749,13 @@ def whitespace_df_dask(whitespace_df_pandas):
 
 
 @pytest.fixture()
-def whitespace_df_koalas(whitespace_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(whitespace_df_pandas)
+def whitespace_df_spark(whitespace_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(whitespace_df_pandas)
 
 
 @pytest.fixture(
-    params=["whitespace_df_pandas", "whitespace_df_dask", "whitespace_df_koalas"]
+    params=["whitespace_df_pandas", "whitespace_df_dask", "whitespace_df_spark"]
 )
 def whitespace_df(request):
     return request.getfixturevalue(request.param)
@@ -762,11 +778,9 @@ def falsy_names_df_dask(falsy_names_df_pandas):
 
 
 @pytest.fixture()
-def falsy_names_df_koalas(falsy_names_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(
+def falsy_names_df_spark(falsy_names_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(
         falsy_names_df_pandas.applymap(
             lambda tup: list(tup) if isinstance(tup, tuple) else tup
         )
@@ -774,7 +788,7 @@ def falsy_names_df_koalas(falsy_names_df_pandas):
 
 
 @pytest.fixture(
-    params=["falsy_names_df_pandas", "falsy_names_df_dask", "falsy_names_df_koalas"]
+    params=["falsy_names_df_pandas", "falsy_names_df_dask", "falsy_names_df_spark"]
 )
 def falsy_names_df(request):
     return request.getfixturevalue(request.param)
@@ -791,7 +805,7 @@ def sample_inferred_logical_types():
         "id": Integer,
         "full_name": Unknown,
         "email": EmailAddress,
-        "phone_number": Unknown,
+        "phone_number": PhoneNumber,
         "age": IntegerNullable,
         "signup_date": Datetime,
         "is_registered": BooleanNullable,
@@ -852,15 +866,13 @@ def serialize_df_dask(serialize_df_pandas):
 
 
 @pytest.fixture()
-def serialize_df_koalas(serialize_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(serialize_df_pandas)
+def serialize_df_spark(serialize_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(serialize_df_pandas)
 
 
 @pytest.fixture(
-    params=["serialize_df_pandas", "serialize_df_dask", "serialize_df_koalas"]
+    params=["serialize_df_pandas", "serialize_df_dask", "serialize_df_spark"]
 )
 def serialize_df(request):
     return request.getfixturevalue(request.param)
@@ -880,11 +892,11 @@ def dask_datetimes(pandas_datetimes):
 
 
 @pytest.fixture()
-def koalas_datetimes(pandas_datetimes):
-    return [pd_to_koalas(series) for series in pandas_datetimes]
+def spark_datetimes(pandas_datetimes):
+    return [pd_to_spark(series) for series in pandas_datetimes]
 
 
-@pytest.fixture(params=["pandas_datetimes", "dask_datetimes", "koalas_datetimes"])
+@pytest.fixture(params=["pandas_datetimes", "dask_datetimes", "spark_datetimes"])
 def datetimes(request):
     return request.getfixturevalue(request.param)
 
@@ -909,13 +921,90 @@ def outliers_df_dask(outliers_df_pandas):
 
 
 @pytest.fixture()
-def outliers_df_koalas(outliers_df_pandas):
-    ks = pytest.importorskip(
-        "databricks.koalas", reason="Koalas not installed, skipping"
-    )
-    return ks.from_pandas(outliers_df_pandas)
+def outliers_df_spark(outliers_df_pandas):
+    ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
+    return ps.from_pandas(outliers_df_pandas)
 
 
-@pytest.fixture(params=["outliers_df_pandas", "outliers_df_dask", "outliers_df_koalas"])
+@pytest.fixture(params=["outliers_df_pandas", "outliers_df_dask", "outliers_df_spark"])
 def outliers_df(request):
     return request.getfixturevalue(request.param)
+
+
+class MockCallback:
+    def __init__(self):
+        self.progress_history = []
+        self.total_update = 0
+        self.total_elapsed_time = 0
+
+    def __call__(self, update, progress, total, unit, time_elapsed):
+        self.total_update += update
+        self.total = total
+        self.progress_history.append(progress)
+        self.unit = unit
+        self.total_elapsed_time = time_elapsed
+
+
+@pytest.fixture()
+def mock_callback():
+    return MockCallback()
+
+
+class MockResultCallback:
+    def __init__(self):
+        self.results_so_far = []
+        self.most_recent_calculation = []
+
+    def __call__(self, results_so_far, most_recent_calculations):
+        self.results_so_far.append(results_so_far)
+        self.most_recent_calculation.append(most_recent_calculations)
+
+
+@pytest.fixture()
+def mock_results_callback():
+    return MockResultCallback()
+
+
+@pytest.fixture()
+def timezones_df_pandas():
+    dtypes = {
+        "default_1": "datetime64[ns]",
+        "utc_1": "datetime64[ns, UTC]",
+        "eastern_1": "datetime64[ns, US/Eastern]",
+        "default_2": "object",
+        "utc_2": "object",
+        "eastern_2": "object",
+    }
+    return pd.DataFrame(
+        data=[
+            [
+                "2022-01-01",
+                "2022-01-01 00:00:00+00:00",
+                "2022-01-01 00:00:00-05:00",
+                "2022-01-01",
+                "2022-01-01T00:00:00+00:00",
+                "2022-01-01 00:00:00-05:00",
+            ],
+            [
+                "2022-01-02",
+                "2022-01-02 00:00:00+00:00",
+                "2022-01-02 00:00:00-05:00",
+                "2022-01-02",
+                "2022-01-02T00:00:00+00:00",
+                "2022-01-02 00:00:00-05:00",
+            ],
+            ["NaT", "NaT", "NaT", "NaT", "NaT", "NaT"],
+        ],
+        columns=["default_1", "utc_1", "eastern_1", "default_2", "utc_2", "eastern_2"],
+    ).astype(dtypes)
+
+
+@pytest.fixture()
+def timezones_df_dask(timezones_df_pandas):
+    dd = pytest.importorskip("dask.dataframe", reason="Dask not installed, skipping")
+    return dd.from_pandas(timezones_df_pandas, npartitions=2)
+
+
+@pytest.fixture(params=["timezones_df_pandas", "timezones_df_dask"])
+def timezones_df(request):
+    return request.getfixturevalue(request.param)
