@@ -9,7 +9,7 @@ from woodwork.logical_types import (
     Datetime,
     Double,
     Integer,
-    NaturalLanguage
+    NaturalLanguage,
 )
 from woodwork.table_schema import TableSchema
 
@@ -17,7 +17,7 @@ from woodwork.table_schema import TableSchema
 @pytest.fixture(autouse=True)
 def set_testing_headers():
     opener = urllib.request.build_opener()
-    opener.addheaders = [('Testing', 'True')]
+    opener.addheaders = [("Testing", "True")]
     urllib.request.install_opener(opener)
 
 
@@ -31,8 +31,8 @@ def test_load_retail_diff():
     assert df.ww.schema is None
     assert df.shape[0] == nrows_second
 
-    assert 'order_product_id' in df.columns
-    assert df['order_product_id'].is_unique
+    assert "order_product_id" in df.columns
+    assert df["order_product_id"].is_unique
 
 
 def test_load_retail():
@@ -40,23 +40,23 @@ def test_load_retail():
     assert isinstance(df.ww.schema, TableSchema)
 
     expected_logical_types = {
-        'order_product_id': Categorical,
-        'order_id': Categorical,
-        'product_id': Categorical,
-        'description': NaturalLanguage,
-        'quantity': Integer,
-        'order_date': Datetime,
-        'unit_price': Double,
-        'customer_name': Categorical,
-        'country': Categorical,
-        'total': Double,
-        'cancelled': Boolean,
+        "order_product_id": Categorical,
+        "order_id": Categorical,
+        "product_id": Categorical,
+        "description": NaturalLanguage,
+        "quantity": Integer,
+        "order_date": Datetime,
+        "unit_price": Double,
+        "customer_name": Categorical,
+        "country": Categorical,
+        "total": Double,
+        "cancelled": Boolean,
     }
 
     for col_name, column in df.ww.columns.items():
         assert isinstance(column.logical_type, expected_logical_types[col_name])
 
-    assert df.ww.index == 'order_product_id'
-    assert df.ww.time_index == 'order_date'
-    assert df.ww.semantic_tags['order_product_id'] == {'index'}
-    assert df.ww.semantic_tags['order_date'] == {'time_index'}
+    assert df.ww.index == "order_product_id"
+    assert df.ww.time_index == "order_date"
+    assert df.ww.semantic_tags["order_product_id"] == {"index"}
+    assert df.ww.semantic_tags["order_date"] == {"time_index"}
