@@ -6,19 +6,19 @@ from woodwork.accessor_utils import (
     _is_dask_dataframe,
     _is_dask_series,
     _is_dataframe,
-    _is_koalas_dataframe,
-    _is_koalas_series,
     _is_series,
+    _is_spark_dataframe,
+    _is_spark_series,
     get_invalid_schema_message,
     init_series,
     is_schema_valid,
 )
 from woodwork.exceptions import TypeConversionError
-from woodwork.logical_types import Categorical, Datetime, NaturalLanguage
+from woodwork.logical_types import Categorical, Datetime, LatLong, NaturalLanguage
 
 
 def test_init_series_valid_conversion_specified_ltype(sample_series):
-    if _is_koalas_series(sample_series):
+    if _is_spark_series(sample_series):
         sample_series = sample_series.astype("str")
     else:
         sample_series = sample_series.astype("object")
@@ -82,7 +82,7 @@ def test_init_series_with_multidimensional_np_array():
 
 
 def test_init_series_valid_conversion_inferred_ltype(sample_series):
-    if _is_koalas_series(sample_series):
+    if _is_spark_series(sample_series):
         sample_series = sample_series.astype("str")
     else:
         sample_series = sample_series.astype("object")
@@ -101,8 +101,15 @@ def test_init_series_with_datetime(sample_datetime_series):
     assert isinstance(series.ww.logical_type, Datetime)
 
 
+def test_init_series_with_latlong(latlong_df):
+    for column in latlong_df:
+        series = latlong_df[column]
+        series = init_series(series, logical_type="LatLong")
+        assert isinstance(series.ww.logical_type, LatLong)
+
+
 def test_init_series_all_parameters(sample_series):
-    if _is_koalas_series(sample_series):
+    if _is_spark_series(sample_series):
         sample_series = sample_series.astype("str")
     else:
         sample_series = sample_series.astype("object")
@@ -134,9 +141,9 @@ def test_init_series_error_on_invalid_conversion(sample_series):
         pytest.xfail(
             "Dask type conversion with astype does not fail until compute is called"
         )
-    if _is_koalas_series(sample_series):
+    if _is_spark_series(sample_series):
         pytest.xfail(
-            "Koalas allows this conversion, filling values it cannot convert with NaN "
+            "Spark allows this conversion, filling values it cannot convert with NaN "
             "and converting dtype to float."
         )
 
@@ -208,14 +215,14 @@ def test_get_invalid_schema_message_dtype_mismatch(sample_df):
         == "dtype mismatch for column is_registered between DataFrame dtype, Int64, and BooleanNullable dtype, boolean"
     )
 
-    # Koalas backup dtypes make these checks not relevant
-    if not _is_koalas_dataframe(sample_df):
+    # Spark backup dtypes make these checks not relevant
+    if not _is_spark_dataframe(sample_df):
         incorrect_str_dtype_df = schema_df.ww.astype(
             {"full_name": "object"}
-        )  # wont work for koalas
+        )  # wont work for spark
         incorrect_categorical_dtype_df = schema_df.ww.astype(
             {"age": "string"}
-        )  # wont work for koalas
+        )  # wont work for spark
         assert (
             get_invalid_schema_message(incorrect_str_dtype_df, schema)
             == "dtype mismatch for column full_name between DataFrame dtype, object, and PersonFullName dtype, string"
@@ -228,7 +235,7 @@ def test_get_invalid_schema_message_dtype_mismatch(sample_df):
 
 def test_get_invalid_schema_message_index_checks(sample_df):
     if not isinstance(sample_df, pd.DataFrame):
-        pytest.xfail("Index validation not performed for Dask or Koalas DataFrames")
+        pytest.xfail("Index validation not performed for Dask or Spark DataFrames")
 
     schema_df = sample_df.copy()
     schema_df.ww.init(
@@ -253,16 +260,20 @@ def test_get_invalid_schema_message_index_checks(sample_df):
         == "Index column is not unique"
     )
 
-    nan_df = pd.DataFrame(
+    df = pd.DataFrame(
         {
-            "id": pd.Series([5, 4, None, 2], dtype="float64"),
+            "id": pd.Series([5, 4, 3, 2], dtype="float64"),
             "col": pd.Series(["b", "b", "b", "d"], dtype="category"),
         }
     )
-    nan_df.ww.init(index="id")
-    nan_df_schema = nan_df.ww.schema
+    df.ww.init(index="id")
+    df_schema = df.ww.schema
 
-    assert get_invalid_schema_message(nan_df, nan_df_schema) is None
+    nan_df = df.replace({3: None})
+    nan_df["id"] = nan_df["id"].astype("float64")
+    nan_df = nan_df.set_index("id", drop=False)
+    actual = get_invalid_schema_message(nan_df, df_schema)
+    assert actual == "Index contains null values"
 
 
 def test_is_schema_valid_true(sample_df):
@@ -294,11 +305,11 @@ def test_is_dask_series(sample_series_dask):
     assert not _is_dask_series(pd.Series())
 
 
-def test_is_koalas_dataframe(sample_df_koalas):
-    assert _is_koalas_dataframe(sample_df_koalas)
+def test_is_spark_dataframe(sample_df_spark):
+    assert _is_spark_dataframe(sample_df_spark)
     assert not _is_dask_dataframe(pd.DataFrame())
 
 
-def test_is_koalas_series(sample_series_koalas):
-    assert _is_koalas_series(sample_series_koalas)
+def test_is_spark_series(sample_series_spark):
+    assert _is_spark_series(sample_series_spark)
     assert not _is_dask_series(pd.Series())
