@@ -1,11 +1,11 @@
 import os
+from unittest.mock import patch
 
 import pandas as pd
 import pytest
-from mock import patch
 
 import woodwork as ww
-from woodwork.serialize import save_orc_file
+from woodwork.serializers.orc_serializer import save_orc_file
 from woodwork.utils import _replace_nan_strings
 
 
