@@ -1,11 +1,12 @@
-import re
+from timeit import default_timer as timer
+from unittest.mock import patch
 
 import numpy as np
 import pandas as pd
 import pytest
-from mock import patch
 
 import woodwork as ww
+from woodwork.exceptions import TypeValidationError
 from woodwork.logical_types import (
     Age,
     AgeFractional,
@@ -14,6 +15,7 @@ from woodwork.logical_types import (
     BooleanNullable,
     Categorical,
     CountryCode,
+    CurrencyCode,
     Datetime,
     Double,
     Integer,
@@ -32,17 +34,19 @@ from woodwork.type_sys.utils import (
     list_semantic_tags,
 )
 from woodwork.utils import (
+    CallbackCaller,
+    _coerce_to_float,
     _convert_input_to_set,
     _get_column_logical_type,
     _infer_datetime_format,
-    _is_null_latlong,
+    _is_latlong_nan,
+    _is_nan,
     _is_s3,
     _is_url,
     _is_valid_latlong_series,
     _is_valid_latlong_value,
     _parse_logical_type,
     _reformat_to_latlong,
-    _to_latlong_float,
     camel_to_snake,
     get_valid_mi_types,
     import_or_none,
@@ -50,7 +54,7 @@ from woodwork.utils import (
 )
 
 dd = import_or_none("dask.dataframe")
-ks = import_or_none("databricks.koalas")
+ps = import_or_none("pyspark.pandas")
 
 
 def test_camel_to_snake():
@@ -212,11 +216,13 @@ def test_get_ltype_params():
     assert params_class == {}
 
     params_null = _get_specified_ltype_params(Datetime())
-    assert params_null == {"datetime_format": None}
+    assert params_null == {"datetime_format": None, "timezone": None}
 
     ymd = "%Y-%m-%d"
-    params_value = _get_specified_ltype_params(Datetime(datetime_format=ymd))
-    assert params_value == {"datetime_format": ymd}
+    params_value = _get_specified_ltype_params(
+        Datetime(datetime_format=ymd, timezone="UTC")
+    )
+    assert params_value == {"datetime_format": ymd, "timezone": "UTC"}
 
 
 def test_import_or_raise():
@@ -242,137 +248,148 @@ def test_is_s3():
     assert not _is_s3("https://woodwork-static.s3.amazonaws.com/")
 
 
-def test_reformat_to_latlong_errors():
-    for latlong in [{1, 2, 3}, "{1, 2, 3}", "This is text"]:
-        error = f"LatLongs must either be a tuple, a list, or a string representation of a tuple. {latlong} does not fit the criteria."
-        with pytest.raises(ValueError, match=error):
-            _reformat_to_latlong(latlong)
-
-    error = re.escape(
-        "LatLongs must either be a tuple, a list, or a string representation of a tuple. (1,2) does not fit the criteria."
-    )
-    with pytest.raises(ValueError, match=error):
-        _reformat_to_latlong("'(1,2)'")
-
-    for latlong in [(1, 2, 3), "(1, 2, 3)"]:
-        error = re.escape(
-            "LatLong values must have exactly two values. (1, 2, 3) does not have two values."
-        )
-        with pytest.raises(ValueError, match=error):
-            _reformat_to_latlong(latlong)
-
-    error = re.escape(
-        "Latitude and Longitude values must be in decimal degrees. The latitude or longitude represented by 41deg52'54\" N cannot be converted to a float."
-    )
-    with pytest.raises(ValueError, match=error):
-        _reformat_to_latlong(("41deg52'54\" N", "21deg22'54\" W"))
+@pytest.mark.parametrize(
+    "test_input, error_msg",
+    [
+        ({1, 2, 3}, "LatLong value is not properly formatted."),
+        ("{1, 2, 3}", "LatLong value is not properly formatted."),
+        ("This is text", "LatLong value is not properly formatted."),
+        ("'(1,2)'", "LatLong value is not properly formatted."),
+        ((1, 2, 3), "LatLong values must have exactly two values"),
+        ("(1, 2, 3)", "LatLong values must have exactly two values"),
+        ("(1,)", "LatLong values must have exactly two values"),
+        (
+            ("41deg52'54\" N", "21deg22'54\" W"),
+            "LatLong values must be in decimal degrees.",
+        ),
+        ((41.5, "21deg22'54\" W"), "LatLong values must be in decimal degrees."),
+    ],
+)
+def test_reformat_to_latlong_errors(test_input, error_msg):
+    with pytest.raises(TypeValidationError, match=error_msg):
+        _reformat_to_latlong(test_input)
 
 
-def test_reformat_to_latlong():
-    simple_latlong = (1, 2)
-
-    assert _reformat_to_latlong((1, 2)) == simple_latlong
-    assert _reformat_to_latlong(("1", "2")) == simple_latlong
-    assert _reformat_to_latlong("(1,2)") == simple_latlong
-
-    # Check non-standard tuple formats
-    assert _reformat_to_latlong([1, 2]) == simple_latlong
-    assert _reformat_to_latlong(["1", "2"]) == simple_latlong
-    assert _reformat_to_latlong("[1, 2]") == simple_latlong
-    assert _reformat_to_latlong("1, 2") == simple_latlong
-
-    assert _reformat_to_latlong(None) is np.nan
-    assert _reformat_to_latlong((1, np.nan)) == (1, np.nan)
-    assert _reformat_to_latlong((np.nan, "1")) == (np.nan, 1)
-
-    # This is how csv and parquet will deserialize
-    assert _reformat_to_latlong("(1, nan)") == (1, np.nan)
-    assert _reformat_to_latlong("(NaN, 9)") == (np.nan, 9)
-
-
-def test_reformat_to_latlong_list():
-    simple_latlong = [1, 2]
-
-    assert _reformat_to_latlong((1, 2), use_list=True) == simple_latlong
-    assert _reformat_to_latlong(("1", "2"), use_list=True) == simple_latlong
-    assert _reformat_to_latlong("(1,2)", use_list=True) == simple_latlong
-
-    assert _reformat_to_latlong([1, 2], use_list=True) == simple_latlong
-    assert _reformat_to_latlong(["1", "2"], use_list=True) == simple_latlong
-    assert _reformat_to_latlong("[1, 2]", use_list=True) == simple_latlong
-    assert _reformat_to_latlong("1, 2", use_list=True) == simple_latlong
-
-    assert _reformat_to_latlong((1, np.nan), use_list=True) == [1, np.nan]
-    assert _reformat_to_latlong((np.nan, "1"), use_list=True) == [np.nan, 1]
-
-    # This is how csv and parquet will deserialize
-    assert _reformat_to_latlong("[1, nan]", use_list=True) == [1, np.nan]
-    assert _reformat_to_latlong("[1, NaN]", use_list=True) == [1, np.nan]
-
-
-def test_to_latlong_float():
-    assert _to_latlong_float(4) == 4.0
-    assert _to_latlong_float("2.2") == 2.2
-
-    assert _to_latlong_float(None) is np.nan
-    assert _to_latlong_float(np.nan) is np.nan
-    assert _to_latlong_float(pd.NA) is np.nan
-
-    error = re.escape(
-        "Latitude and Longitude values must be in decimal degrees. The latitude or longitude represented by [1, 2, 3] cannot be converted to a float."
-    )
-    with pytest.raises(ValueError, match=error):
-        _to_latlong_float([1, 2, 3])
-
-
-def test_is_null_latlong():
-    assert _is_null_latlong(None)
-    assert _is_null_latlong(np.nan)
-    assert _is_null_latlong(pd.NA)
-    assert _is_null_latlong("None")
-    assert _is_null_latlong("nan")
-    assert _is_null_latlong("NaN")
-
-    assert not _is_null_latlong([None, 1, 3])
-    assert not _is_null_latlong("none")
-    assert not _is_null_latlong(0)
-    assert not _is_null_latlong(False)
-
-
-def test_is_valid_latlong_value():
-    values = [
-        (1.0, 2.0),
-        np.nan,
-        [1.0, 2.0],
+@pytest.mark.parametrize(
+    "test_input,expected",
+    [
+        ((1, 2), (1, 2)),
+        (("1", "2"), (1, 2)),
+        ("(1,2)", (1, 2)),
+        ([1, 2], (1, 2)),
+        (["1", "2"], (1, 2)),
+        ("[1, 2]", (1, 2)),
+        ("1, 2", (1, 2)),
+        ((1, np.nan), (1, np.nan)),
+        ((np.nan, "1"), (np.nan, 1)),
+        ("(1, nan)", (1, np.nan)),
+        ("(NaN, 9)", (np.nan, 9)),
+        ("(1, None)", (1, np.nan)),
+        ("(<NA>, 9)", (np.nan, 9)),
+        ((np.nan, np.nan), (np.nan, np.nan)),
+        ((pd.NA, pd.NA), (np.nan, np.nan)),
+        ((None, None), (np.nan, np.nan)),
+        (None, np.nan),
         (np.nan, np.nan),
-        ("a", 2.0),
-        (1.0, 2.0, 3.0),
-        None,
-    ]
-
-    expected_values = [True, True, False, False, False, False, False]
-
-    for index, value in enumerate(values):
-        assert _is_valid_latlong_value(value) is expected_values[index]
+        (pd.NA, np.nan),
+        ("None", np.nan),
+        ("NaN", np.nan),
+        ("<NA>", np.nan),
+    ],
+)
+@pytest.mark.parametrize("is_spark", [True, False])
+def test_reformat_to_latlong(test_input, expected, is_spark):
+    if isinstance(expected, (list, tuple)):
+        if is_spark:
+            assert _reformat_to_latlong(test_input, is_spark) == list(expected)
+        else:
+            assert _reformat_to_latlong(test_input, is_spark) == expected
+    else:
+        assert _reformat_to_latlong(test_input) is expected
 
 
-def test_is_valid_latlong_value_koalas():
-    values = [
-        (1.0, 2.0),
-        np.nan,
-        [1.0, 2.0],
+@pytest.mark.parametrize(
+    "test_input,expected",
+    [
+        (4, 4.0),
+        ("2.2", 2.2),
+        (None, np.nan),
         (np.nan, np.nan),
-        ("a", 2.0),
-        (1.0, 2.0, 3.0),
-        None,
-    ]
+        (pd.NA, np.nan),
+    ],
+)
+def test_coerce_to_float(test_input, expected):
+    if np.isnan(expected):
+        assert _coerce_to_float(test_input) is expected
+    else:
+        assert _coerce_to_float(test_input) == expected
 
-    expected_values = [False, True, True, False, False, False, False]
 
-    for index, value in enumerate(values):
-        assert (
-            _is_valid_latlong_value(value, bracket_type=list) is expected_values[index]
-        )
+def test_is_nan():
+    assert _is_nan(None)
+    assert _is_nan(np.nan)
+    assert _is_nan(pd.NA)
+    assert _is_nan("None")
+    assert _is_nan("nan")
+    assert _is_nan("NaN")
+    assert _is_nan("<NA>")
+    assert _is_nan("")
+    assert _is_nan("null")
+
+    assert not _is_nan([None, 1, 3])
+    assert not _is_nan([])
+    assert not _is_nan("none")
+    assert not _is_nan(0)
+    assert not _is_nan(False)
+    assert not _is_nan({"key": "value"})
+
+
+@pytest.mark.parametrize(
+    "test_input,expected",
+    [
+        ((1.0, 2.0), True),
+        ((1.0, np.nan), True),
+        ((np.nan, 2.0), True),
+        ((np.nan, np.nan), True),
+        (np.nan, True),
+        (pd.NA, False),
+        (2.0, False),
+        ([2.0], False),
+        ([None, None], False),
+        ("None", False),
+        ([1.0, 2.0], False),
+        ((pd.NA, pd.NA), False),
+        (("a", 2.0), False),
+        ((1.0, 2.0, 3.0), False),
+        (None, False),
+    ],
+)
+def test_is_valid_latlong_value(test_input, expected):
+    assert _is_valid_latlong_value(test_input) == expected
+
+
+@pytest.mark.parametrize(
+    "test_input,expected",
+    [
+        ([1.0, 2.0], True),
+        ([1.0, np.nan], True),
+        ([np.nan, 2.0], True),
+        ([np.nan, np.nan], True),
+        (np.nan, True),
+        (None, True),
+        (pd.NA, False),
+        (2.0, False),
+        ([2.0], False),
+        ([None, None], False),
+        ("None", False),
+        ((1.0, 2.0), False),
+        ((pd.NA, pd.NA), False),
+        (("a", 2.0), False),
+        ((1.0, 2.0, 3.0), False),
+    ],
+)
+def test_is_valid_latlong_value_spark(test_input, expected):
+    assert _is_valid_latlong_value(test_input, is_spark=True) == expected
 
 
 def test_is_valid_latlong_series():
@@ -393,6 +410,7 @@ def test_get_valid_mi_types():
         BooleanNullable,
         Categorical,
         CountryCode,
+        CurrencyCode,
         Datetime,
         Double,
         Integer,
@@ -498,8 +516,8 @@ def test_infer_datetime_format_all_null():
         if dd:
             dd_series = dd.from_pandas(pd_series, npartitions=2)
             assert _infer_datetime_format(dd_series) is None
-        if ks:
-            ks_series = ks.from_pandas(pd_series)
+        if ps:
+            ks_series = ps.from_pandas(pd_series)
             assert _infer_datetime_format(ks_series) is None
 
 
@@ -522,3 +540,64 @@ def test_is_categorical() -> None:
     assert _is_categorical_series(pd.Series([1, 1]), 0.5)
     assert _is_categorical_series(pd.Series([1, 2, 1, 1]), 0.5)
     assert _is_categorical_series(pd.Series([1, 2, 3, 1]), 0.75)
+
+
+def test_is_latlong_nan():
+    assert _is_latlong_nan((np.nan, np.nan))
+    assert _is_latlong_nan([np.nan, np.nan])
+    assert _is_latlong_nan((np.nan,))
+    assert _is_latlong_nan(np.nan)
+    assert not _is_latlong_nan((np.nan, 2.0))
+    assert not _is_latlong_nan([np.nan, 2.0])
+    assert not _is_latlong_nan((2.0, 3.0))
+    assert not _is_latlong_nan("test")
+
+
+def test_callback_caller(mock_callback):
+    unit = "yards"
+    total = 100
+    caller = CallbackCaller(callback=mock_callback, unit=unit, total=total)
+    start_time = caller.start_time
+
+    assert mock_callback.total_update == 0
+    assert caller.total == total
+    assert caller.unit == unit
+    assert caller.current_progress == 0
+    assert isinstance(start_time, float)
+
+    caller.update(50)
+    assert mock_callback.unit == unit
+    assert mock_callback.total_update == 50
+    assert caller.current_progress == 50
+    assert mock_callback.total_elapsed_time > 0
+    assert mock_callback.progress_history == [50]
+
+
+def test_callback_caller_defaults(mock_callback):
+    unit = "yards"
+    total = 100
+    start_time = timer()
+    caller = CallbackCaller(
+        callback=mock_callback,
+        unit=unit,
+        total=total,
+        start_time=start_time,
+        start_progress=20,
+    )
+
+    assert caller.start_time == start_time
+    assert caller.current_progress == 20
+
+
+def test_callback_caller_no_callback():
+    unit = "yards"
+    total = 100
+    caller = CallbackCaller(callback=None, unit=unit, total=total)
+
+    assert caller.callback is None
+    assert caller.total == 100
+    assert caller.current_progress == 0
+
+    caller.update(1)
+
+    assert caller.current_progress == 0
