@@ -3,11 +3,13 @@ import importlib
 import re
 from inspect import isclass
 from mimetypes import add_type, guess_type
+from timeit import default_timer as timer
 
 import numpy as np
 import pandas as pd
 
 import woodwork as ww
+from woodwork.exceptions import TypeValidationError
 from woodwork.pandas_backport import guess_datetime_format
 
 # Dictionary mapping formats/content types to the appropriate pandas read function
@@ -214,55 +216,66 @@ def _is_url(string):
     return "http" in string
 
 
-def _reformat_to_latlong(latlong, use_list=False):
-    """Reformats LatLong columns to be tuples of floats. Uses np.nan for null values."""
-    if _is_null_latlong(latlong):
-        return np.nan
-
+def _reformat_to_latlong(latlong, is_spark=False):
+    """
+    Accepts 2-tuple like values, or a single NaN like value.
+    NaN like values are replaced with np.nan.
+    """
     if isinstance(latlong, str):
+
+        nan_values = [x for x in ww.config.get_option("nan_values") if len(x)]
+        nan_values = "|".join(nan_values)
+
+        latlong = re.sub(nan_values, "None", latlong)
+
         try:
-            # Serialized latlong columns from csv or parquet will be strings, so null values will be
-            # read as the string 'nan' in pandas and Dask and 'NaN' in Koalas
-            # neither of which which is interpretable as a null value
-            if "nan" in latlong:
-                latlong = latlong.replace("nan", "None")
-            if "NaN" in latlong:
-                latlong = latlong.replace("NaN", "None")
             latlong = ast.literal_eval(latlong)
         except ValueError:
             pass
 
-    if isinstance(latlong, (tuple, list)):
+    if isinstance(latlong, (list, tuple)):
         if len(latlong) != 2:
-            raise ValueError(
+            raise TypeValidationError(
                 f"LatLong values must have exactly two values. {latlong} does not have two values."
             )
 
-        latitude, longitude = map(_to_latlong_float, latlong)
+        latitude, longitude = latlong
 
-        # (np.nan, np.nan) should be counted as a single null value
-        if pd.isnull(latitude) and pd.isnull(longitude):
-            return np.nan
+        try:
+            latitude = _coerce_to_float(latitude)
+            longitude = _coerce_to_float(longitude)
+        except ValueError:
+            raise TypeValidationError(
+                f"LatLong values must be in decimal degrees. {latlong} does not have latitude or longitude values that can be converted to a float."
+            )
 
-        if use_list:
+        if is_spark:
             return [latitude, longitude]
         return (latitude, longitude)
 
-    raise ValueError(
-        f"LatLongs must either be a tuple, a list, or a string representation of a tuple. {latlong} does not fit the criteria."
+    if _is_nan(latlong):
+        return np.nan
+
+    raise TypeValidationError(
+        f"""LatLong value is not properly formatted. Value must be one of the following:
+- A 2-tuple or list of 2 values representing decimal latitude or longitude values (NaN values are allowed).
+- A single NaN value.
+- A string representation of the above.
+
+{latlong} does not fit the criteria."""
     )
 
 
-def _to_latlong_float(val):
+def _coerce_to_float(val):
     """Attempts to convert a value to a float, propagating null values."""
-    if _is_null_latlong(val):
+    if _is_nan(val):
         return np.nan
 
     try:
         return float(val)
     except (ValueError, TypeError):
         raise ValueError(
-            f"Latitude and Longitude values must be in decimal degrees. The latitude or longitude represented by {val} cannot be converted to a float."
+            f"The value represented by {val} cannot be converted to a float."
         )
 
 
@@ -270,37 +283,56 @@ def _is_valid_latlong_series(series):
     """Returns True if all elements in the series contain properly formatted LatLong values,
     otherwise returns False"""
     if ww.accessor_utils._is_dask_series(series):
-        series = series = series.get_partition(0).compute()
-    if ww.accessor_utils._is_koalas_series(series):
+        series = series.get_partition(0).compute()
+    if ww.accessor_utils._is_spark_series(series):
         series = series.to_pandas()
-        bracket_type = list
+        is_spark = True
     else:
-        bracket_type = tuple
-    if series.apply(_is_valid_latlong_value, args=(bracket_type,)).all():
+        is_spark = False
+    if series.apply(_is_valid_latlong_value, args=(is_spark,)).all():
         return True
     return False
 
 
-def _is_valid_latlong_value(val, bracket_type=tuple):
+def _is_valid_latlong_value(val, is_spark=False):
     """Returns True if the value provided is a properly formatted LatLong value for a
-    pandas, Dask or Koalas Series, otherwise returns False."""
-    if isinstance(val, bracket_type) and len(val) == 2:
+    pandas, Dask or Spark Series, otherwise returns False."""
+    if isinstance(val, (list, tuple)):
+        if len(val) != 2:
+            return False
+
+        if not isinstance(val, list if is_spark else tuple):
+            return False
+
         latitude, longitude = val
-        if isinstance(latitude, float) and isinstance(longitude, float):
-            if pd.isnull(latitude) and pd.isnull(longitude):
-                return False
-            return True
-    elif isinstance(val, float) and pd.isnull(val):
+        return isinstance(latitude, float) and isinstance(longitude, float)
+
+    if isinstance(val, float):
+        return np.isnan(val)
+
+    if is_spark and val is None:
         return True
+
     return False
 
 
-def _is_null_latlong(val):
-    if isinstance(val, str):
-        return val == "None" or val == "nan" or val == "NaN"
+def _is_nan(value):
+    """This function checks if string values are common NaN values.
+    Lists are not counted as NaN, and all other values are passed to pd.isnull
+    """
+    if isinstance(value, str):
+        return value in ww.config.get_option("nan_values")
+    if isinstance(value, list):
+        return False
+    return pd.isnull(value)
 
-    # Since we can have list inputs here, pd.isnull will not have a relevant truth value for lists
-    return not isinstance(val, list) and pd.isnull(val)
+
+def _is_latlong_nan(value):
+    """Checks if a LatLong value is NaN"""
+    if isinstance(value, (tuple, list)):
+        return all([_is_nan(x) for x in value])
+
+    return _is_nan(value)
 
 
 def get_valid_mi_types():
@@ -331,6 +363,28 @@ def get_valid_mi_types():
     return valid_types
 
 
+def get_valid_pearson_types():
+    """
+    Generate a list of LogicalTypes that are valid for calculating Pearson correlation. Note that
+    index columns are not valid for calculating dependence, but their types may be
+    returned by this function.
+
+    Args:
+        None
+
+    Returns:
+        list(LogicalType): A list of the LogicalTypes that can be use to calculate Pearson correlation
+    """
+    valid_types = []
+    for ltype in ww.type_system.registered_types:
+        if "numeric" in ltype.standard_tags:
+            valid_types.append(ltype)
+        elif ltype == ww.logical_types.Datetime:
+            valid_types.append(ltype)
+
+    return valid_types
+
+
 def _get_column_logical_type(series, logical_type, name):
     if logical_type:
         return _parse_logical_type(logical_type, name)
@@ -443,13 +497,13 @@ def concat_columns(objs, validate_schema=True):
     # Perform concatenation with the correct library
     obj = objs[0]
     dd = import_or_none("dask.dataframe")
-    ks = import_or_none("databricks.koalas")
+    ps = import_or_none("pyspark.pandas")
 
     lib = pd
-    if ww.accessor_utils._is_koalas_dataframe(
+    if ww.accessor_utils._is_spark_dataframe(obj) or ww.accessor_utils._is_spark_series(
         obj
-    ) or ww.accessor_utils._is_koalas_series(obj):
-        lib = ks
+    ):
+        lib = ps
     elif ww.accessor_utils._is_dask_dataframe(obj) or ww.accessor_utils._is_dask_series(
         obj
     ):
@@ -475,18 +529,10 @@ def concat_columns(objs, validate_schema=True):
     return combined_df
 
 
-def _update_progress(
-    start_time,
-    current_time,
-    progress_increment,
-    current_progress,
-    total,
-    unit,
-    callback_function,
-):
-    """Helper function for updating progress of a function and making a call to the progress callback
-    function, if provided. Adds the progress increment to the current progress amount and returns the
-    updated progress amount.
+class CallbackCaller:
+    """
+    Helper class for updating progress of a function and making a call to the progress callback
+    function, if provided. Adds the progress increment to the current progress.
 
     If provided, the callback function should accept the following parameters:
         - update (int): change in progress since last call
@@ -494,13 +540,40 @@ def _update_progress(
         - total (int): the total number of calculations to do
         - unit (str): unit of measurement for progress/total
         - time_elapsed (float): total time in seconds elapsed since start of call
-    """
-    if callback_function is not None:
-        new_progress = current_progress + progress_increment
-        elapsed_time = current_time - start_time
-        callback_function(progress_increment, new_progress, total, unit, elapsed_time)
 
-        return new_progress
+    """
+
+    def __init__(self, callback, unit, total, start_time=None, start_progress=0):
+        """
+        Args:
+            callback (func): callback method to call
+            unit (str): unit of measurement for progress/total
+            total (int): the total number of calculations to do
+            start_time (datetime): when time started for the callback.  Defaults
+                to when the class instance is created
+            start_progress (int): starting progress for the callback.  Defaults to 0.
+        """
+        if start_time is not None:
+            self.start_time = start_time
+        else:
+            self.start_time = timer()
+        self.callback = callback
+        self.unit = unit
+        self.current_progress = start_progress
+        self.total = total
+
+    def update(self, progress_increment):
+        """
+        Args:
+            progress_increment (int): change in progress since the last call
+        """
+        if self.callback is not None:
+            elapsed_time = timer() - self.start_time
+            new_progress = self.current_progress + progress_increment
+            self.callback(
+                progress_increment, new_progress, self.total, self.unit, elapsed_time
+            )
+            self.current_progress = new_progress
 
 
 def _infer_datetime_format(dates, n=100):
@@ -510,6 +583,11 @@ def _infer_datetime_format(dates, n=100):
         n (int): the maximum number of nonnull rows to sample from the series
     """
     first_n = dates.dropna().head(n)
+
+    ps = import_or_none("pyspark.pandas")
+    if ps and isinstance(first_n, ps.series.Series):
+        first_n = first_n.to_pandas()
+
     if len(first_n) == 0:
         return None
     try:
@@ -520,7 +598,7 @@ def _infer_datetime_format(dates, n=100):
     return mode_fmt
 
 
-def _replace_nan_strings(df):
+def _replace_nan_strings(df: pd.DataFrame) -> pd.DataFrame:
     """Replaces empty string values and string representations of
     NaN values ("nan", "<NA>") with np.nan or pd.NA depending on
     column dtype."""
@@ -538,7 +616,7 @@ def _replace_nan_strings(df):
 
         replaced_series = df[col].replace(r"^\s*$", replace_val, regex=True)
         replaced_series = replaced_series.replace(
-            {"nan": replace_val, "<NA>": replace_val}
+            ww.config.get_option("nan_values"), replace_val
         )
         df[col] = replaced_series
 
